summaryrefslogtreecommitdiffstats
path: root/generic/tclExecute.c
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2013-05-19 20:26:29 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2013-05-19 20:26:29 (GMT)
commitbf486a2007f9d3d45855d43e623ad85d29bcd0b7 (patch)
tree9b32f20f3f9f59fc35ff74967c61992a71b394ff /generic/tclExecute.c
parent2576405f10bb1194c302b2582428451d6f52d998 (diff)
parent349564d2ad254c318eb5f8ac46ef2597621cd4ee (diff)
downloadtcl-bf486a2007f9d3d45855d43e623ad85d29bcd0b7.zip
tcl-bf486a2007f9d3d45855d43e623ad85d29bcd0b7.tar.gz
tcl-bf486a2007f9d3d45855d43e623ad85d29bcd0b7.tar.bz2
Don't #define VOID on VxWorks, as it is already typdef'd to void. Eliminate possibly conflicting LOCAL/OFFSET
Diffstat (limited to 'generic/tclExecute.c')
-rw-r--r--generic/tclExecute.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/generic/tclExecute.c b/generic/tclExecute.c
index 904c368..0de8e3c 100644
--- a/generic/tclExecute.c
+++ b/generic/tclExecute.c
@@ -836,13 +836,13 @@ TclFinalizeExecution(void)
(TCL_ALLOCALIGN/sizeof(Tcl_Obj *))
/*
* OFFSET computes how many words have to be skipped until the next aligned
* word. Note that we are only interested in the low order bits of ptr, so
* that any possible information loss in PTR2INT is of no consequence.
*/
static inline int
-OFFSET(
+wordSkip(
void *ptr)
{
int mask = TCL_ALLOCALIGN-1;
@@ -855,7 +855,7 @@ OFFSET(
*/
#define MEMSTART(markerPtr) \
- ((markerPtr) + OFFSET(markerPtr))
+ ((markerPtr) + wordSkip(markerPtr))
/*
@@ -900,7 +900,7 @@ GrowEvaluationStack(
}
} else {
Tcl_Obj **tmpMarkerPtr = esPtr->tosPtr + 1;
- int offset = OFFSET(tmpMarkerPtr);
+ int offset = wordSkip(tmpMarkerPtr);
if (needed + offset < 0) {
/*
@@ -836,13 +836,13 @@ TclFinalizeExecution(void)
(TCL_ALLOCALIGN/sizeof(Tcl_Obj *))
/*
- * OFFSET computes how many words have to be skipped until the next aligned
+ * wordSkip computes how many words have to be skipped until the next aligned
* word. Note that we are only interested in the low order bits of ptr, so
* that any possible information loss in PTR2INT is of no consequence.